# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: waMsgApplication/WAMsgApplication.proto
# Protobuf Python Version: 5.28.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    2,
    '',
    'waMsgApplication/WAMsgApplication.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from waCommon import WACommon_pb2 as waCommon_dot_WACommon__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'waMsgApplication/WAMsgApplication.proto\x12\x10WAMsgApplication\x1a\x17waCommon/WACommon.proto\"\xb5\x11\n\x12MessageApplication\x12=\n\x07payload\x18\x01 \x01(\x0b\x32,.WAMsgApplication.MessageApplication.Payload\x12?\n\x08metadata\x18\x02 \x01(\x0b\x32-.WAMsgApplication.MessageApplication.Metadata\x1a\x8c\x08\n\x08Metadata\x12U\n\x14\x63hatEphemeralSetting\x18\x01 \x01(\x0b\x32\x35.WAMsgApplication.MessageApplication.EphemeralSettingH\x00\x12\x61\n\x14\x65phemeralSettingList\x18\x02 \x01(\x0b\x32\x41.WAMsgApplication.MessageApplication.Metadata.EphemeralSettingMapH\x00\x12\x1f\n\x15\x65phemeralSharedSecret\x18\x03 \x01(\x0cH\x00\x12\x17\n\x0f\x66orwardingScore\x18\x05 \x01(\r\x12\x13\n\x0bisForwarded\x18\x06 \x01(\x08\x12/\n\x10\x62usinessMetadata\x18\x07 \x01(\x0b\x32\x15.WACommon.SubProtocol\x12\x13\n\x0b\x66rankingKey\x18\x08 \x01(\x0c\x12\x17\n\x0f\x66rankingVersion\x18\t \x01(\x05\x12R\n\rquotedMessage\x18\n \x01(\x0b\x32;.WAMsgApplication.MessageApplication.Metadata.QuotedMessage\x12L\n\nthreadType\x18\x0b \x01(\x0e\x32\x38.WAMsgApplication.MessageApplication.Metadata.ThreadType\x12!\n\x19readonlyMetadataDataclass\x18\x0c \x01(\t\x12\x0f\n\x07groupID\x18\r \x01(\t\x12\x11\n\tgroupSize\x18\x0e \x01(\r\x12\x12\n\ngroupIndex\x18\x0f \x01(\r\x12\x15\n\rbotResponseID\x18\x10 \x01(\t\x12\x15\n\rcollapsibleID\x18\x11 \x01(\t\x12\x15\n\rsecondaryOtid\x18\x12 \x01(\t\x1a\x88\x01\n\rQuotedMessage\x12\x10\n\x08stanzaID\x18\x01 \x01(\t\x12\x11\n\tremoteJID\x18\x02 \x01(\t\x12\x13\n\x0bparticipant\x18\x03 \x01(\t\x12=\n\x07payload\x18\x04 \x01(\x0b\x32,.WAMsgApplication.MessageApplication.Payload\x1aw\n\x13\x45phemeralSettingMap\x12\x0f\n\x07\x63hatJID\x18\x01 \x01(\t\x12O\n\x10\x65phemeralSetting\x18\x02 \x01(\x0b\x32\x35.WAMsgApplication.MessageApplication.EphemeralSetting\"E\n\nThreadType\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x00\x12\x0f\n\x0bVANISH_MODE\x10\x01\x12\x19\n\x15\x44ISAPPEARING_MESSAGES\x10\x02\x42\x0b\n\tephemeral\x1a\xb9\x02\n\x07Payload\x12\x43\n\x0b\x63oreContent\x18\x01 \x01(\x0b\x32,.WAMsgApplication.MessageApplication.ContentH\x00\x12=\n\x06signal\x18\x02 \x01(\x0b\x32+.WAMsgApplication.MessageApplication.SignalH\x00\x12O\n\x0f\x61pplicationData\x18\x03 \x01(\x0b\x32\x34.WAMsgApplication.MessageApplication.ApplicationDataH\x00\x12N\n\x0bsubProtocol\x18\x04 \x01(\x0b\x32\x37.WAMsgApplication.MessageApplication.SubProtocolPayloadH\x00\x42\t\n\x07\x63ontent\x1a\xed\x02\n\x12SubProtocolPayload\x12\x30\n\x0f\x63onsumerMessage\x18\x02 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12\x30\n\x0f\x62usinessMessage\x18\x03 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12/\n\x0epaymentMessage\x18\x04 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12,\n\x0bmultiDevice\x18\x05 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12%\n\x04voip\x18\x06 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12*\n\tarmadillo\x18\x07 \x01(\x0b\x32\x15.WACommon.SubProtocolH\x00\x12\x32\n\x0b\x66utureProof\x18\x01 \x01(\x0e\x32\x1d.WACommon.FutureProofBehaviorB\r\n\x0bsubProtocol\x1a\x11\n\x0f\x41pplicationData\x1a\x08\n\x06Signal\x1a\t\n\x07\x43ontent\x1a\xbb\x02\n\x10\x45phemeralSetting\x12\x1b\n\x13\x65phemeralExpiration\x18\x02 \x01(\r\x12!\n\x19\x65phemeralSettingTimestamp\x18\x03 \x01(\x03\x12`\n\x10\x65phemeralityType\x18\x05 \x01(\x0e\x32\x46.WAMsgApplication.MessageApplication.EphemeralSetting.EphemeralityType\x12\x1f\n\x17isEphemeralSettingReset\x18\x04 \x01(\x08\"d\n\x10\x45phemeralityType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\r\n\tSEEN_ONCE\x10\x01\x12\x19\n\x15SEEN_BASED_WITH_TIMER\x10\x02\x12\x19\n\x15SEND_BASED_WITH_TIMER\x10\x03\x42,Z*go.mau.fi/whatsmeow/proto/waMsgApplication')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'waMsgApplication.WAMsgApplication_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z*go.mau.fi/whatsmeow/proto/waMsgApplication'
  _globals['_MESSAGEAPPLICATION']._serialized_start=87
  _globals['_MESSAGEAPPLICATION']._serialized_end=2316
  _globals['_MESSAGEAPPLICATION_METADATA']._serialized_start=238
  _globals['_MESSAGEAPPLICATION_METADATA']._serialized_end=1274
  _globals['_MESSAGEAPPLICATION_METADATA_QUOTEDMESSAGE']._serialized_start=933
  _globals['_MESSAGEAPPLICATION_METADATA_QUOTEDMESSAGE']._serialized_end=1069
  _globals['_MESSAGEAPPLICATION_METADATA_EPHEMERALSETTINGMAP']._serialized_start=1071
  _globals['_MESSAGEAPPLICATION_METADATA_EPHEMERALSETTINGMAP']._serialized_end=1190
  _globals['_MESSAGEAPPLICATION_METADATA_THREADTYPE']._serialized_start=1192
  _globals['_MESSAGEAPPLICATION_METADATA_THREADTYPE']._serialized_end=1261
  _globals['_MESSAGEAPPLICATION_PAYLOAD']._serialized_start=1277
  _globals['_MESSAGEAPPLICATION_PAYLOAD']._serialized_end=1590
  _globals['_MESSAGEAPPLICATION_SUBPROTOCOLPAYLOAD']._serialized_start=1593
  _globals['_MESSAGEAPPLICATION_SUBPROTOCOLPAYLOAD']._serialized_end=1958
  _globals['_MESSAGEAPPLICATION_APPLICATIONDATA']._serialized_start=1960
  _globals['_MESSAGEAPPLICATION_APPLICATIONDATA']._serialized_end=1977
  _globals['_MESSAGEAPPLICATION_SIGNAL']._serialized_start=1979
  _globals['_MESSAGEAPPLICATION_SIGNAL']._serialized_end=1987
  _globals['_MESSAGEAPPLICATION_CONTENT']._serialized_start=1989
  _globals['_MESSAGEAPPLICATION_CONTENT']._serialized_end=1998
  _globals['_MESSAGEAPPLICATION_EPHEMERALSETTING']._serialized_start=2001
  _globals['_MESSAGEAPPLICATION_EPHEMERALSETTING']._serialized_end=2316
  _globals['_MESSAGEAPPLICATION_EPHEMERALSETTING_EPHEMERALITYTYPE']._serialized_start=2216
  _globals['_MESSAGEAPPLICATION_EPHEMERALSETTING_EPHEMERALITYTYPE']._serialized_end=2316
# @@protoc_insertion_point(module_scope)



from __future__ import annotations
from enum import Enum
import magic
import typing
from ..proto.waE2E.WAWebProtobufsE2E_pb2 import (
    Message,
    ImageMessage,
    AudioMessage,
    VideoMessage,
    DocumentMessage,
)
from .message import get_message_type


class MediaTypeToMMS(Enum):
    MediaImage = "image"
    MediaAudio = "audio"
    MediaVideo = "video"
    MediaDocument = "document"
    MediaHistory = "md-msg-hist"
    MediaAppState = "md-app-state"
    MediaLinkThumbnail = "thumbnail-link"

    @classmethod
    def from_message(cls, message: Message):
        return {
            ImageMessage: cls.MediaImage,
            AudioMessage: cls.MediaAudio,
            VideoMessage: cls.MediaVideo,
            DocumentMessage: cls.MediaDocument,
        }[type(get_message_type(message))]

    @classmethod
    def from_mime(cls, mime: str):
        type_ = mime.split("/")[0]
        return {
            "audio": cls.MediaAudio,
            "video": cls.MediaVideo,
            "image": cls.MediaImage,
        }.get(type_, cls.MediaDocument)


class MediaType(Enum):
    MediaImage = 0
    MediaVideo = 1
    MediaAudio = 2
    MediaDocument = 3
    MediaHistory = 4
    MediaAppState = 5
    MediaLinkThumbnail = 6

    @classmethod
    def from_magic(cls, fn_or_bytes: typing.Union[str, bytes]) -> MediaType:
        """Returns the MediaType based on file magic bytes or file extension.

        :param fn_or_bytes: Either a file path (str) or binary data (bytes) for determining the MediaType.
        :type fn_or_bytes: typing.Union[str, bytes]
        :return: The determined MediaType.
        :rtype: MediaType
        """
        magic_func = magic.from_file if isinstance(fn_or_bytes, str) else magic.from_buffer
        mime = magic_func(fn_or_bytes, mime=True).split("/")[0]
        match mime:
            case "image":
                return cls.MediaImage
            case "video":
                return cls.MediaVideo
            case "audio":
                return cls.MediaAudio
            case _:
                return cls.MediaDocument


class ChatPresence(Enum):
    """
    Enum representing the presence status in a chat.

    Attributes:
        CHAT_PRESENCE_COMPOSING (int): Indicates that the user is currently composing a message.
        CHAT_PRESENCE_PAUSED (int): Indicates that the user has paused composing a message.
    """

    CHAT_PRESENCE_COMPOSING = 0
    CHAT_PRESENCE_PAUSED = 1


class ChatPresenceMedia(Enum):
    """
    Enum representing the type of media being used in a chat.

    Attributes:
        CHAT_PRESENCE_MEDIA_TEXT (int): Indicates that the chat media type is text.
        CHAT_PRESENCE_MEDIA_AUDIO (int): Indicates that the chat media type is audio.
    """

    CHAT_PRESENCE_MEDIA_TEXT = 0
    CHAT_PRESENCE_MEDIA_AUDIO = 1


class LogLevel(Enum):
    """
    Enum representing the different levels of logging.

    Attributes:
        NOTSET (int): Logging level not set, represented by -1.
        DEBUG (int): Debug level, represented by 0.
        INFO (int): Information level, represented by 1.
        WARN (int): Warning level, represented by 2.
        ERROR (int): Error level, represented by 3.
    """

    NOTSET = -1
    DEBUG = 0
    INFO = 1
    WARN = 2
    ERROR = 3

    @property
    def level(self) -> bytes:
        """
        Returns the logging level name encoded as bytes.

        Returns:
            bytes: The name of the logging level encoded in bytes. If the level is NOTSET, returns an empty byte string.
        """
        if self is self.NOTSET:
            return b""
        return self.name.encode()

    @classmethod
    def from_logging(cls, level: int):
        """
        Converts a numeric logging level to a corresponding LogLevel enum member.

        Args:
            level (int): Numeric value representing the logging level.

        Returns:
            LogLevel: The corresponding LogLevel enum member.
        """
        match level:
            case 50:
                return cls.ERROR
            case 40:
                return cls.ERROR
            case 30:
                return cls.WARN
            case 20:
                return cls.INFO
            case 10:
                return cls.DEBUG
            case 0:
                return cls.NOTSET
        return cls.INFO

    def log_level(self) -> int:
        """
        Converts the LogLevel enum member to its corresponding numeric logging level.

        Returns:
            int: The numeric value representing the logging level.
        """
        return (self.value + 1) * 10


class ReceiptType(Enum):
    """
    Enum representing different types of message receipts.

    Attributes:
        DELIVERED (bytes): Indicates that the message has been delivered.
        SENDER (bytes): Indicates that the message is from the sender.
        RETRY (bytes): Indicates a retry receipt.
        READ (bytes): Indicates that the message has been read.
        READ_SELF (bytes): Indicates that the message has been read by the sender themselves.
        PLAYED (bytes): Indicates that the message has been played (e.g., for audio messages).
        PLAYED_SELF (bytes): Indicates that the message has been played by the sender themselves.
        SERVER_ERROR (bytes): Indicates a server error receipt.
        INACTIVE (bytes): Indicates that the recipient is inactive.
        PEER_MSG (bytes): Indicates a peer message receipt.
        HISTORY_SYNC (str): Indicates that the message is part of a history sync.
    """

    DELIVERED = b""
    SENDER = b"sender"
    RETRY = b"RETRY"
    READ = b"read"
    READ_SELF = b"read-self"
    PLAYED = b"played"
    PLAYED_SELF = b"played-self"
    SERVER_ERROR = b"server-error"
    INACTIVE = b"inactive"
    PEER_MSG = b"peer_msg"
    HISTORY_SYNC = "hist_sync"


class ClientType(Enum):
    """
    Enumeration of client types.

    Attributes:
        UNKNOWN (int): Unknown client type.
        CHROME (int): Chrome browser.
        EDGE (int): Microsoft Edge browser.
        FIREFOX (int): Mozilla Firefox browser.
        IE (int): Internet Explorer browser.
        OPERA (int): Opera browser.
        SAFARI (int): Safari browser.
        ELECTRON (int): Electron framework.
        UWP (int): Universal Windows Platform.
        OTHER (int): Other client types.
    """

    UNKNOWN = 0
    CHROME = 1
    EDGE = 2
    FIREFOX = 3
    IE = 4
    OPERA = 5
    SAFARI = 6
    ELECTRON = 7
    UWP = 8
    OTHER = 9

    @property
    def name(self) -> str:
        """
        Returns the title-cased name of the client type.

        :return: The title-cased name.
        :rtype: str
        """
        return super().name.title()


class ClientName(Enum):
    """
    Enumeration of client names.

    Attributes:
        LINUX (str): Linux operating system.
        WINDOWS (str): Windows operating system.
        ANDROID (str): Android operating system.
    """

    LINUX = "linux"
    WINDOWS = "windows nt"
    ANDROID = "android"

    @property
    def name(self) -> str:
        """
        Returns the title-cased name of the client.

        :return: The title-cased name.
        :rtype: str
        """
        return super().name.title()


class PrivacySettingType(Enum):
    """
    Enumeration of privacy setting types.

    Attributes:
        GROUP_ADD (str): Group add privacy setting.
        LAST_SEEN (str): Last seen privacy setting.
        STATUS (str): Status privacy setting.
        PROFILE (str): Profile privacy setting.
        READ_RECEIPTS (str): Read receipts privacy setting.
        ONLINE (str): Online privacy setting.
        CALL_ADD (str): Call add privacy setting.
    """

    GROUP_ADD = "groupadd"
    LAST_SEEN = "last"
    STATUS = "status"
    PROFILE = "profile"
    READ_RECEIPTS = "readreceipts"
    ONLINE = "online"
    CALL_ADD = "calladd"


class PrivacySetting(Enum):
    """
    Enumeration of privacy settings.

    Attributes:
        UNDEFINED (str): Undefined privacy setting.
        ALL (str): All privacy setting.
        CONTACTS (str): Contacts privacy setting.
        CONTACTS_BLACKLIST (str): Contacts blacklist privacy setting.
        MATCH_LAST_SEEN (str): Match last seen privacy setting.
        KNOWN (str): Known privacy setting.
        NONE (str): None privacy setting.
    """

    UNDEFINED = ""
    ALL = "all"
    CONTACTS = "contacts"
    CONTACTS_BLACKLIST = "contacts_blacklist"
    MATCH_LAST_SEEN = "match_last_seen"
    KNOWN = "known"
    NONE = "none"


class BlocklistAction(Enum):
    """
    Enumeration of blocklist actions.

    Attributes:
        BLOCK (str): Block action.
        UNBLOCK (str): Unblock action.
    """

    BLOCK = "block"
    UNBLOCK = "unblock"


class ParticipantChange(Enum):
    """
    Enumeration of participant change actions.

    Attributes:
        ADD (str): Add participant action.
        REMOVE (str): Remove participant action.
        PROMOTE (str): Promote participant action.
        DEMOTE (str): Demote participant action.
    """

    ADD = "add"
    REMOVE = "remove"
    PROMOTE = "promote"
    DEMOTE = "demote"


class ParticipantRequestChange(Enum):
    """
    Enumeration of participant request change actions.

    Attributes:
        APPROVE (str): Approve participant request action.
        REJECT (str): Reject participant request action.
    """

    APPROVE = "approve"
    REJECT = "reject"


class Presence(Enum):
    AVAILABLE = b"available"
    UNAVAILABLE = b"unavailable"

class VoteType(Enum):
    """
    Enumeration of vote types.

    Attributes:
        MULTIPLE (int): Allows selecting multiple options in a poll.
        SINGLE (int): Allows selecting only a single option in a poll.
    """

    MULTIPLE = 0
    SINGLE = 1